# Change Log

## [0.2.1](https://github.com/dldevinc/django-spectrum/tree/v0.2.1) - 2021-02-17
- Fix missing templates

## [0.2.0](https://github.com/dldevinc/django-spectrum/tree/v0.2.0) - 2021-02-13
- `Color` class has been changed in a **backward incompatible** way
- Drop Python 3.4 support
- Migrate to [pickr](https://github.com/Simonwep/pickr)
